==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/datasync/kotlin/inputs/LocationFsxOntapFileSystemProtocolSmbMountOptionsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.datasync.kotlin.inputs

import com.pulumi.aws.datasync.inputs.LocationFsxOntapFileSystemProtocolSmbMountOptionsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property version The specific NFS version that you want DataSync to use for mounting your NFS share. Valid values: `NFS3`. Default: `NFS3`
 */
public data class LocationFsxOntapFileSystemProtocolSmbMountOptionsArgs(
    public val version: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.datasync.inputs.LocationFsxOntapFileSystemProtocolSmbMountOptionsArgs> {
    override fun toJava():
        com.pulumi.aws.datasync.inputs.LocationFsxOntapFileSystemProtocolSmbMountOptionsArgs =
        com.pulumi.aws.datasync.inputs.LocationFsxOntapFileSystemProtocolSmbMountOptionsArgs.builder()
            .version(version?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LocationFsxOntapFileSystemProtocolSmbMountOptionsArgs].
 */
@PulumiTagMarker
public class LocationFsxOntapFileSystemProtocolSmbMountOptionsArgsBuilder internal constructor() {
    private var version: Output<String>? = null

    /**
     * @param value The specific NFS version that you want DataSync to use for mounting your NFS share. Valid values: `NFS3`. Default: `NFS3`
     */
    @JvmName("spgauimmlertixcg")
    public suspend fun version(`value`: Output<String>) {
        this.version = value
    }

    /**
     * @param value The specific NFS version that you want DataSync to use for mounting your NFS share. Valid values: `NFS3`. Default: `NFS3`
     */
    @JvmName("pvpixrqygrqgvsmo")
    public suspend fun version(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.version = mapped
    }

    internal fun build(): LocationFsxOntapFileSystemProtocolSmbMountOptionsArgs =
        LocationFsxOntapFileSystemProtocolSmbMountOptionsArgs(
            version = version,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/datasync/kotlin/inputs/LocationFsxOntapFileSystemProtocolSmbMountOptionsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.datasync.kotlin.inputs

import com.pulumi.aws.datasync.inputs.LocationFsxOntapFileSystemProtocolSmbMountOptionsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property version
 */
public data class LocationFsxOntapFileSystemProtocolSmbMountOptionsArgs(
    public val version: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.datasync.inputs.LocationFsxOntapFileSystemProtocolSmbMountOptionsArgs> {
    override fun toJava(): com.pulumi.aws.datasync.inputs.LocationFsxOntapFileSystemProtocolSmbMountOptionsArgs =
        com.pulumi.aws.datasync.inputs.LocationFsxOntapFileSystemProtocolSmbMountOptionsArgs.builder()
            .version(version?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [LocationFsxOntapFileSystemProtocolSmbMountOptionsArgs].
 */
@PulumiTagMarker
public class LocationFsxOntapFileSystemProtocolSmbMountOptionsArgsBuilder internal constructor() {
    private var version: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("vnstiqickiggoquy")
    public suspend fun version(`value`: Output<String>) {
        this.version = value
    }

    /**
     * @param value
     */
    @JvmName("vlydehdnngomduir")
    public suspend fun version(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.version = mapped
    }

    internal fun build(): LocationFsxOntapFileSystemProtocolSmbMountOptionsArgs =
        LocationFsxOntapFileSystemProtocolSmbMountOptionsArgs(
            version = version,
        )
}
